==> kubernetes-model-1.0.29-sources.jar: io/fabric8/kubernetes/api/model/SecurityContextFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class SecurityContextFluentImpl<T extends SecurityContextFluent<T>> extends BaseFluent<T> implements SecurityContextFluent<T>{

     VisitableBuilder<Capabilities, ?> capabilities;     Boolean privileged;     Boolean runAsNonRoot;     Long runAsUser;     VisitableBuilder<SELinuxOptions, ?> seLinuxOptions;     Map<String, Object> additionalProperties = new HashMap();

    public Capabilities getCapabilities(){
    return this.capabilities!=null?this.capabilities.build():null;
    }
    public T withCapabilities( Capabilities capabilities){
    if (capabilities!=null){ this.capabilities= new CapabilitiesBuilder(capabilities); _visitables.add(this.capabilities);} return (T) this;
    }
    public CapabilitiesNested<T> withNewCapabilities(){
    return new CapabilitiesNestedImpl<T>();
    }
    public CapabilitiesNested<T> withNewCapabilitiesLike( Capabilities item){
    return new CapabilitiesNestedImpl<T>(item);
    }
    public CapabilitiesNested<T> editCapabilities(){
    return withNewCapabilitiesLike(getCapabilities());
    }
    public Boolean isPrivileged(){
    return this.privileged;
    }
    public T withPrivileged( Boolean privileged){
    this.privileged=privileged; return (T) this;
    }
    public Boolean isRunAsNonRoot(){
    return this.runAsNonRoot;
    }
    public T withRunAsNonRoot( Boolean runAsNonRoot){
    this.runAsNonRoot=runAsNonRoot; return (T) this;
    }
    public Long getRunAsUser(){
    return this.runAsUser;
    }
    public T withRunAsUser( Long runAsUser){
    this.runAsUser=runAsUser; return (T) this;
    }
    public SELinuxOptions getSeLinuxOptions(){
    return this.seLinuxOptions!=null?this.seLinuxOptions.build():null;
    }
    public T withSeLinuxOptions( SELinuxOptions seLinuxOptions){
    if (seLinuxOptions!=null){ this.seLinuxOptions= new SELinuxOptionsBuilder(seLinuxOptions); _visitables.add(this.seLinuxOptions);} return (T) this;
    }
    public SeLinuxOptionsNested<T> withNewSeLinuxOptions(){
    return new SeLinuxOptionsNestedImpl<T>();
    }
    public SeLinuxOptionsNested<T> withNewSeLinuxOptionsLike( SELinuxOptions item){
    return new SeLinuxOptionsNestedImpl<T>(item);
    }
    public SeLinuxOptionsNested<T> editSeLinuxOptions(){
    return withNewSeLinuxOptionsLike(getSeLinuxOptions());
    }
    public T withNewSeLinuxOptions( String level,  String role,  String type,  String user){
    return withSeLinuxOptions(new SELinuxOptions(level, role, type, user));
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
SecurityContextFluentImpl that = (SecurityContextFluentImpl) o;
if (capabilities != null ? !capabilities.equals(that.capabilities) :that.capabilities != null) return false;
if (privileged != null ? !privileged.equals(that.privileged) :that.privileged != null) return false;
if (runAsNonRoot != null ? !runAsNonRoot.equals(that.runAsNonRoot) :that.runAsNonRoot != null) return false;
if (runAsUser != null ? !runAsUser.equals(that.runAsUser) :that.runAsUser != null) return false;
if (seLinuxOptions != null ? !seLinuxOptions.equals(that.seLinuxOptions) :that.seLinuxOptions != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class CapabilitiesNestedImpl<N> extends CapabilitiesFluentImpl<CapabilitiesNested<N>> implements CapabilitiesNested<N>{

        private final CapabilitiesBuilder builder;
    
             CapabilitiesNestedImpl (){
        this.builder = new CapabilitiesBuilder(this);
        }
             CapabilitiesNestedImpl ( Capabilities item){
        this.builder = new CapabilitiesBuilder(this, item);
        }
    
            public N endCapabilities(){
            return and();
        }
            public N and(){
            return (N) SecurityContextFluentImpl.this.withCapabilities(builder.build());
        }
    
}
    public class SeLinuxOptionsNestedImpl<N> extends SELinuxOptionsFluentImpl<SeLinuxOptionsNested<N>> implements SeLinuxOptionsNested<N>{

        private final SELinuxOptionsBuilder builder;
    
             SeLinuxOptionsNestedImpl (){
        this.builder = new SELinuxOptionsBuilder(this);
        }
             SeLinuxOptionsNestedImpl ( SELinuxOptions item){
        this.builder = new SELinuxOptionsBuilder(this, item);
        }
    
            public N endSeLinuxOptions(){
            return and();
        }
            public N and(){
            return (N) SecurityContextFluentImpl.this.withSeLinuxOptions(builder.build());
        }
    
}


}

==> kubernetes-model-1.0.43-sources.jar: io/fabric8/kubernetes/api/model/SecurityContextFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.Map;
import java.util.Map;
import java.util.HashMap;
import java.io.Serializable;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;

public class SecurityContextFluentImpl<T extends SecurityContextFluent<T>> extends BaseFluent<T> implements SecurityContextFluent<T>{

     VisitableBuilder<Capabilities, ?> capabilities;     Boolean privileged;     Boolean runAsNonRoot;     Long runAsUser;     VisitableBuilder<SELinuxOptions, ?> seLinuxOptions;     Map<String, Object> additionalProperties = new HashMap();
public SecurityContextFluentImpl(){
    
}
public SecurityContextFluentImpl( SecurityContext instance ){
    this.withCapabilities(instance.getCapabilities()); this.withPrivileged(instance.getPrivileged()); this.withRunAsNonRoot(instance.getRunAsNonRoot()); this.withRunAsUser(instance.getRunAsUser()); this.withSeLinuxOptions(instance.getSeLinuxOptions()); 
}

    public Capabilities getCapabilities(){
    return this.capabilities!=null?this.capabilities.build():null;
    }
    public T withCapabilities( Capabilities capabilities){
    if (capabilities!=null){ this.capabilities= new CapabilitiesBuilder(capabilities); _visitables.add(this.capabilities);} return (T) this;
    }
    public CapabilitiesNested<T> withNewCapabilities(){
    return new CapabilitiesNestedImpl<T>();
    }
    public CapabilitiesNested<T> withNewCapabilitiesLike( Capabilities item){
    return new CapabilitiesNestedImpl<T>(item);
    }
    public CapabilitiesNested<T> editCapabilities(){
    return withNewCapabilitiesLike(getCapabilities());
    }
    public Boolean isPrivileged(){
    return this.privileged;
    }
    public T withPrivileged( Boolean privileged){
    this.privileged=privileged; return (T) this;
    }
    public Boolean isRunAsNonRoot(){
    return this.runAsNonRoot;
    }
    public T withRunAsNonRoot( Boolean runAsNonRoot){
    this.runAsNonRoot=runAsNonRoot; return (T) this;
    }
    public Long getRunAsUser(){
    return this.runAsUser;
    }
    public T withRunAsUser( Long runAsUser){
    this.runAsUser=runAsUser; return (T) this;
    }
    public SELinuxOptions getSeLinuxOptions(){
    return this.seLinuxOptions!=null?this.seLinuxOptions.build():null;
    }
    public T withSeLinuxOptions( SELinuxOptions seLinuxOptions){
    if (seLinuxOptions!=null){ this.seLinuxOptions= new SELinuxOptionsBuilder(seLinuxOptions); _visitables.add(this.seLinuxOptions);} return (T) this;
    }
    public SeLinuxOptionsNested<T> withNewSeLinuxOptions(){
    return new SeLinuxOptionsNestedImpl<T>();
    }
    public SeLinuxOptionsNested<T> withNewSeLinuxOptionsLike( SELinuxOptions item){
    return new SeLinuxOptionsNestedImpl<T>(item);
    }
    public SeLinuxOptionsNested<T> editSeLinuxOptions(){
    return withNewSeLinuxOptionsLike(getSeLinuxOptions());
    }
    public T withNewSeLinuxOptions( String level,  String role,  String type,  String user){
    return withSeLinuxOptions(new SELinuxOptions(level, role, type, user));
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
SecurityContextFluentImpl that = (SecurityContextFluentImpl) o;
if (capabilities != null ? !capabilities.equals(that.capabilities) :that.capabilities != null) return false;
if (privileged != null ? !privileged.equals(that.privileged) :that.privileged != null) return false;
if (runAsNonRoot != null ? !runAsNonRoot.equals(that.runAsNonRoot) :that.runAsNonRoot != null) return false;
if (runAsUser != null ? !runAsUser.equals(that.runAsUser) :that.runAsUser != null) return false;
if (seLinuxOptions != null ? !seLinuxOptions.equals(that.seLinuxOptions) :that.seLinuxOptions != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class CapabilitiesNestedImpl<N> extends CapabilitiesFluentImpl<CapabilitiesNested<N>> implements CapabilitiesNested<N>{

        private final CapabilitiesBuilder builder;
    
             CapabilitiesNestedImpl (){
        this.builder = new CapabilitiesBuilder(this);
        }
             CapabilitiesNestedImpl ( Capabilities item){
        this.builder = new CapabilitiesBuilder(this, item);
        }
    
            public N endCapabilities(){
            return and();
        }
            public N and(){
            return (N) SecurityContextFluentImpl.this.withCapabilities(builder.build());
        }
    
}
    public class SeLinuxOptionsNestedImpl<N> extends SELinuxOptionsFluentImpl<SeLinuxOptionsNested<N>> implements SeLinuxOptionsNested<N>{

        private final SELinuxOptionsBuilder builder;
    
             SeLinuxOptionsNestedImpl (){
        this.builder = new SELinuxOptionsBuilder(this);
        }
             SeLinuxOptionsNestedImpl ( SELinuxOptions item){
        this.builder = new SELinuxOptionsBuilder(this, item);
        }
    
            public N endSeLinuxOptions(){
            return and();
        }
            public N and(){
            return (N) SecurityContextFluentImpl.this.withSeLinuxOptions(builder.build());
        }
    
}


}
